@@ -72,7 +72,10 @@ def _blockm(block_method, table, outfile, x, y, z, **kwargs):
     a="aspatial",
     f="coltypes",
     i="incols",
+    o="outcols",
     r="registration",
+    s="skiprows",
+    w="wrap",
 )
 @kwargs_to_strings(R="sequence")
 def blockmean(table=None, outfile=None, *, x=None, y=None, z=None, **kwargs):
@@ -112,7 +115,10 @@ def blockmean(table=None, outfile=None, *, x=None, y=None, z=None, **kwargs):
     {a}
     {i}
     {f}
+    {o}
     {r}
+    {s}
+    {w}
 
     Returns
     -------
@@ -137,7 +143,10 @@ def blockmean(table=None, outfile=None, *, x=None, y=None, z=None, **kwargs):
     a="aspatial",
     f="coltypes",
     i="incols",
+    o="outcols",
     r="registration",
+    s="skiprows",
+    w="wrap",
 )
 @kwargs_to_strings(R="sequence")
 def blockmedian(table=None, outfile=None, *, x=None, y=None, z=None, **kwargs):
@@ -177,7 +186,10 @@ def blockmedian(table=None, outfile=None, *, x=None, y=None, z=None, **kwargs):
     {a}
     {f}
     {i}
+    {o}
     {r}
+    {s}
+    {w}
 
     Returns
     -------
