@@ -68,6 +68,15 @@ def grdclip(grid, **kwargs):
         Set all data[i] == *old* to *new*. This is mostly useful when
         your data are known to be integer values.
     {V}
+
+    Returns
+    -------
+    ret: xarray.DataArray or None
+        Return type depends on whether the ``outgrid`` parameter is set:
+
+        - :class:`xarray.DataArray` if ``outgrid`` is not set
+        - None if ``outgrid`` is set (grid output will be stored in file set by
+          ``outgrid``)
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
