@@ -24,6 +24,7 @@ from pygmt.helpers import (
     T="toggle",
     V="verbose",
     f="coltypes",
+    r="registration",
 )
 @kwargs_to_strings(R="sequence")
 def grdfilter(grid, **kwargs):
@@ -96,10 +97,7 @@ def grdfilter(grid, **kwargs):
         5: grid (x,y) in Mercator ``projection='m1'`` img units, *width* in km,
         Spherical distance calculation.
 
-    spacing : str
-        *xinc*\[\ *unit*\][**+e**\|\ **n**]
-        [/*yinc*\ [*unit*][**+e**\|\ **n**]].
-        *xinc* [and optionally *yinc*] is the grid spacing.
+    {I}
     nans : str or float
         **i**\|\ **p**\|\ **r**.
         Determine how NaN-values in the input grid affects the filtered output.
@@ -110,6 +108,7 @@ def grdfilter(grid, **kwargs):
         input grid].
     {V}
     {f}
+    {r}
 
     Returns
     -------
