@@ -17,7 +17,15 @@ from pygmt.helpers import (
 
 
 @fmt_docstring
-@use_alias(I="spacing", R="region", G="outfile", V="verbose", f="coltypes")
+@use_alias(
+    I="spacing",
+    R="region",
+    G="outfile",
+    V="verbose",
+    a="aspatial",
+    f="coltypes",
+    r="registration",
+)
 @kwargs_to_strings(R="sequence")
 def surface(x=None, y=None, z=None, data=None, **kwargs):
     r"""
@@ -46,10 +54,7 @@ def surface(x=None, y=None, z=None, data=None, **kwargs):
     data : str or 2d array
         Either a data file name or a 2d numpy array with the tabular data.
 
-    spacing : str
-        *xinc*\[\ *unit*\][**+e**\|\ **n**]\
-        [/*yinc*\ [*unit*][**+e**\|\ **n**]].
-        *xinc* [and optionally *yinc*] is the grid spacing.
+    {I}
 
     region : str or list
         *xmin/xmax/ymin/ymax*\[**+r**][**+u**\ *unit*].
@@ -60,7 +65,9 @@ def surface(x=None, y=None, z=None, data=None, **kwargs):
         to store the grid in.
 
     {V}
+    {a}
     {f}
+    {r}
 
     Returns
     -------
