@@ -19,7 +19,12 @@ from pygmt.helpers import build_arg_string, fmt_docstring, kwargs_to_strings, us
     X="xshift",
     Y="yshift",
     Z="scale",
+    b="binary",
     c="panel",
+    d="nodata",
+    e="find",
+    g="gap",
+    h="header",
     i="columns",
     p="perspective",
 )
@@ -75,7 +80,12 @@ def wiggle(self, x=None, y=None, z=None, data=None, **kwargs):
     pen : str
         Specify outline pen attributes [Default is no outline].
     {XY}
+    {b}
     {c}
+    {d}
+    {e}
+    {g}
+    {h}
     columns : str or 1d array
         Choose which columns are x, y, and z, respectively if input is provided
         via *data*. E.g. ``columns = [0, 1, 2]`` or ``columns = "0,1,2"`` if
