@@ -62,11 +62,11 @@ def test_contour_fail_no_data(data):
             z=data[:, 2],
             data=data,
             region=region,
-            projection="X4i",
+            projection="X10c",
             style="c0.2c",
             color="red",
             frame="afg",
-            pen="",
+            pen=True,
         )
 
 
@@ -83,7 +83,7 @@ def test_contour_vec(region):
     y = y.flatten()
     z = (x - 0.5 * (region[0] + region[1])) ** 2 + 4 * y ** 2
     z = np.exp(-z / 10 ** 2 * np.log(2))
-    fig.contour(x=x, y=y, z=z, projection="X4i", region=region, frame="a", pen="")
+    fig.contour(x=x, y=y, z=z, projection="X10c", region=region, frame="a", pen=True)
     return fig
 
 
@@ -93,7 +93,7 @@ def test_contour_matrix(data, region):
     Plot data.
     """
     fig = Figure()
-    fig.contour(data=data, projection="X3i", region=region, frame="ag", pen="")
+    fig.contour(data=data, projection="X10c", region=region, frame="ag", pen=True)
     return fig
 
 
@@ -104,6 +104,40 @@ def test_contour_from_file(region):
     """
     fig = Figure()
     fig.contour(
-        data=POINTS_DATA, projection="X4i", region=region, frame="af", pen="#ffcb87"
+        data=POINTS_DATA, projection="X10c", region=region, frame="af", pen="#ffcb87"
     )
     return fig
+
+
+@pytest.mark.mpl_image_compare(filename="test_contour_vec.png")
+def test_contour_deprecate_columns_to_incols(region):
+    """
+    Make sure that the old parameter "columns" is supported and it reports an
+    warning.
+
+    Modified from the test_contour_vec() test.
+    """
+    fig = Figure()
+    x, y = np.meshgrid(
+        np.linspace(region[0], region[1]), np.linspace(region[2], region[3])
+    )
+    x = x.flatten()
+    y = y.flatten()
+    z = (x - 0.5 * (region[0] + region[1])) ** 2 + 4 * y ** 2
+    z = np.exp(-z / 10 ** 2 * np.log(2))
+
+    # generate dataframe
+    # switch x and y from here onwards to simulate different column order
+    data = np.array([y, x, z]).T
+
+    with pytest.warns(expected_warning=FutureWarning) as record:
+        fig.contour(
+            data=data,
+            projection="X10c",
+            region=region,
+            frame="a",
+            pen=True,
+            columns=[1, 0, 2],
+        )
+        assert len(record) == 1  # check that only one warning was raised
+    return fig
