@@ -1,20 +1,14 @@
 """
 Test Figure.grdimage.
 """
-import sys
-
 import numpy as np
 import pytest
 import xarray as xr
-from packaging.version import Version
-from pygmt import Figure, clib
+from pygmt import Figure
 from pygmt.datasets import load_earth_relief
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers.testing import check_figures_equal
 
-with clib.Session() as _lib:
-    gmt_version = Version(_lib.info["version"])
-
 
 @pytest.fixture(scope="module", name="grid")
 def fixture_grid():
@@ -24,6 +18,18 @@ def fixture_grid():
     return load_earth_relief(registration="gridline")
 
 
+@pytest.fixture(scope="module", name="grid_360")
+def fixture_grid_360(grid):
+    """
+    Earth relief grid with longitude range from 0 to 360 (instead of -180 to
+    180).
+    """
+    _grid = grid.copy()  # get a copy of original earth_relief grid
+    _grid.encoding.pop("source")  # unlink earth_relief NetCDF source
+    _grid["lon"] = np.arange(0, 361, 1)  # convert longitude from -180:180 to 0:360
+    return _grid
+
+
 @pytest.fixture(scope="module", name="xrgrid")
 def fixture_xrgrid():
     """
@@ -82,14 +88,6 @@ def test_grdimage_file():
     return fig
 
 
-@pytest.mark.skipif(
-    gmt_version <= Version("6.1.1") and sys.platform == "darwin",
-    reason="Upstream bug in GMT 6.1.1 that causes segfault on macOS",
-)
-@pytest.mark.xfail(
-    condition=gmt_version <= Version("6.1.1") and sys.platform != "darwin",
-    reason="Upstream bug in GMT 6.1.1 that causes this test to fail on Linux/Windows",
-)
 @check_figures_equal()
 @pytest.mark.parametrize(
     "shading",
@@ -119,6 +117,26 @@ def test_grdimage_shading_xarray(grid, shading):
     return fig_ref, fig_test
 
 
+@pytest.mark.xfail(
+    reason="Incorrect scaling of geo CPT on xarray.DataArray grdimage plot."
+    "See https://github.com/GenericMappingTools/gmt/issues/5294",
+)
+@check_figures_equal()
+def test_grdimage_grid_and_shading_with_xarray(grid, xrgrid):
+    """
+    Test that shading works well when xarray.DataArray is input to both the
+    ``grid`` and ``shading`` arguments.
+    """
+    fig_ref, fig_test = Figure(), Figure()
+    fig_ref.grdimage(
+        grid="@earth_relief_01d_g", region="GL", cmap="geo", shading=xrgrid, verbose="i"
+    )
+    fig_ref.colorbar()
+    fig_test.grdimage(grid=grid, region="GL", cmap="geo", shading=xrgrid, verbose="i")
+    fig_test.colorbar()
+    return fig_ref, fig_test
+
+
 def test_grdimage_fails():
     """
     Should fail for unrecognized input.
@@ -145,6 +163,29 @@ def test_grdimage_over_dateline(xrgrid):
     return fig
 
 
+@pytest.mark.mpl_image_compare
+def test_grdimage_global_subset(grid_360):
+    """
+    Ensure subsets of grids are plotted correctly on a global map.
+
+    Specifically checking that xarray.DataArray grids can wrap around the left
+    and right sides on a Mollweide projection (W) plot correctly. Note that a
+    Cartesian grid is used here instead of a Geographic grid (i.e.
+    GMT_GRID_IS_CARTESIAN). This is a regression test for
+    https://github.com/GenericMappingTools/pygmt/issues/732.
+    """
+    # Get a slice of South America and Africa only (lat=-90:31, lon=-180:41)
+    sliced_grid = grid_360[0:121, 0:221]
+    assert sliced_grid.gmt.registration == 0  # gridline registration
+    assert sliced_grid.gmt.gtype == 0  # Cartesian coordinate system
+
+    fig = Figure()
+    fig.grdimage(
+        grid=sliced_grid, cmap="vik", region="g", projection="W0/3.5c", frame=True
+    )
+    return fig
+
+
 @check_figures_equal()
 @pytest.mark.parametrize("lon0", [0, 123, 180])
 @pytest.mark.parametrize("proj_type", ["H", "W"])
