@@ -9,7 +9,6 @@ from pygmt import Figure, makecpt
 from pygmt.datasets import load_earth_relief
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import GMTTempFile
-from pygmt.helpers.testing import check_figures_equal
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
 POINTS_DATA = os.path.join(TEST_DATA_DIR, "points.txt")
@@ -40,7 +39,7 @@ def fixture_grid():
 
 
 @pytest.mark.mpl_image_compare
-def test_makecpt_to_plot_points(points, region):
+def test_makecpt_plot_points(points, region):
     """
     Use static color palette table to change color of points.
     """
@@ -58,34 +57,29 @@ def test_makecpt_to_plot_points(points, region):
 
 
 @pytest.mark.mpl_image_compare
-def test_makecpt_to_plot_grid(grid):
+def test_makecpt_plot_grid(grid):
     """
     Use static color palette table to change color of grid.
     """
     fig = Figure()
     makecpt(cmap="relief")
-    fig.grdimage(grid, projection="W0/6i")
+    fig.grdimage(grid, projection="W0/10c")
     return fig
 
 
-@check_figures_equal()
-def test_makecpt_to_plot_grid_scaled_with_series(grid):
+@pytest.mark.mpl_image_compare
+def test_makecpt_plot_grid_scaled_with_series(grid):
     """
     Use static color palette table scaled to a min/max series to change color
     of grid.
     """
-    # Use single-character arguments for the reference image
-    fig_ref = Figure()
-    makecpt(C="oleron", T="-4500/4500")
-    fig_ref.grdimage(grid, J="W0/6i")
-
-    fig_test = Figure()
-    makecpt(cmap="oleron", series="-4500/4500")
-    fig_test.grdimage(grid, projection="W0/6i")
-    return fig_ref, fig_test
+    fig = Figure()
+    makecpt(cmap="oleron", series=[-4500, 4500])
+    fig.grdimage(grid, projection="W0/10c")
+    return fig
 
 
-def test_makecpt_output_to_cpt_file():
+def test_makecpt_output_cpt_file():
     """
     Save the generated static color palette table to a .cpt file.
     """
@@ -111,35 +105,13 @@ def test_makecpt_invalid_output():
 
 
 @pytest.mark.mpl_image_compare
-def test_makecpt_truncated_to_zlow_zhigh(grid):
+def test_makecpt_truncated_zlow_zhigh(grid):
     """
     Use static color palette table that is truncated to z-low and z-high.
     """
     fig = Figure()
     makecpt(cmap="rainbow", truncate=[0.15, 0.85], series=[-4500, 4500])
-    fig.grdimage(grid, projection="W0/6i")
-    return fig
-
-
-@pytest.mark.mpl_image_compare
-def test_makecpt_truncated_at_zlow_only(grid):
-    """
-    Use static color palette table that is truncated at z-low only.
-    """
-    fig = Figure()
-    makecpt(cmap="rainbow", truncate=[0.5, None], series=[-4500, 4500])
-    fig.grdimage(grid, projection="W0/6i")
-    return fig
-
-
-@pytest.mark.mpl_image_compare
-def test_makecpt_truncated_at_zhigh_only(grid):
-    """
-    Use static color palette table that is truncated at z-high only.
-    """
-    fig = Figure()
-    makecpt(cmap="rainbow", truncate=[None, 0.5], series=[-4500, 4500])
-    fig.grdimage(grid, projection="W0/6i")
+    fig.grdimage(grid, projection="W0/10c")
     return fig
 
 
@@ -150,18 +122,7 @@ def test_makecpt_reverse_color_only(grid):
     """
     fig = Figure()
     makecpt(cmap="earth", reverse=True)
-    fig.grdimage(grid, projection="W0/6i")
-    return fig
-
-
-@pytest.mark.mpl_image_compare
-def test_makecpt_reverse_zsign_only(grid):
-    """
-    Use static color palette table with its z-value sign reversed.
-    """
-    fig = Figure()
-    makecpt(cmap="earth", reverse="z")
-    fig.grdimage(grid, projection="W0/6i")
+    fig.grdimage(grid, projection="W0/10c")
     return fig
 
 
@@ -173,7 +134,7 @@ def test_makecpt_reverse_color_and_zsign(grid):
     """
     fig = Figure()
     makecpt(cmap="earth", reverse="cz")
-    fig.grdimage(grid, projection="W0/6i")
+    fig.grdimage(grid, projection="W0/10c")
     return fig
 
 
@@ -184,39 +145,31 @@ def test_makecpt_continuous(grid):
     scaled from -4500 to 4500m.
     """
     fig = Figure()
-    makecpt(cmap="blue,white", continuous=True, series="-4500,4500")
-    fig.grdimage(grid, projection="W0/6i")
+    makecpt(cmap="blue,white", continuous=True, series=[-4500, 4500])
+    fig.grdimage(grid, projection="W0/10c")
     return fig
 
 
-@check_figures_equal()
+@pytest.mark.mpl_image_compare
 def test_makecpt_categorical(region):
     """
     Use static color palette table that is categorical.
     """
-    fig_ref = Figure()
-    makecpt(C="categorical", W="")
-    fig_ref.colorbar(cmap=True, region=region, frame=True, position="JBC")
-
-    fig_test = Figure()
+    fig = Figure()
     makecpt(cmap="categorical", categorical=True)
-    fig_test.colorbar(cmap=True, region=region, frame=True, position="JBC")
-    return fig_ref, fig_test
+    fig.colorbar(cmap=True, region=region, frame=True, position="JBC")
+    return fig
 
 
-@check_figures_equal()
+@pytest.mark.mpl_image_compare
 def test_makecpt_cyclic(region):
     """
     Use static color palette table that is cyclic.
     """
-    fig_ref = Figure()
-    makecpt(C="cork", W="w")
-    fig_ref.colorbar(cmap=True, region=region, frame=True, position="JBC")
-
-    fig_test = Figure()
+    fig = Figure()
     makecpt(cmap="cork", cyclic=True)
-    fig_test.colorbar(cmap=True, region=region, frame=True, position="JBC")
-    return fig_ref, fig_test
+    fig.colorbar(cmap=True, region=region, frame=True, position="JBC")
+    return fig
 
 
 def test_makecpt_categorical_and_cyclic():
